==> tencentcloud-sdk-java-3.1.209-sources.jar: com/tencentcloudapi/ba/v20200720/models/CreateWeappQRUrlRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ba.v20200720.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreateWeappQRUrlRequest extends AbstractModel{

    /**
    * 代理角色临时密钥的Token
    */
    @SerializedName("SessionKey")
    @Expose
    private String SessionKey;

    /**
     * Get 代理角色临时密钥的Token 
     * @return SessionKey 代理角色临时密钥的Token
     */
    public String getSessionKey() {
        return this.SessionKey;
    }

    /**
     * Set 代理角色临时密钥的Token
     * @param SessionKey 代理角色临时密钥的Token
     */
    public void setSessionKey(String SessionKey) {
        this.SessionKey = SessionKey;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SessionKey", this.SessionKey);

    }
}

==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/ba/v20200720/models/CreateWeappQRUrlRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ba.v20200720.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreateWeappQRUrlRequest extends AbstractModel{

    /**
    * 代理角色临时密钥的Token
    */
    @SerializedName("SessionKey")
    @Expose
    private String SessionKey;

    /**
     * Get 代理角色临时密钥的Token 
     * @return SessionKey 代理角色临时密钥的Token
     */
    public String getSessionKey() {
        return this.SessionKey;
    }

    /**
     * Set 代理角色临时密钥的Token
     * @param SessionKey 代理角色临时密钥的Token
     */
    public void setSessionKey(String SessionKey) {
        this.SessionKey = SessionKey;
    }

    public CreateWeappQRUrlRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CreateWeappQRUrlRequest(CreateWeappQRUrlRequest source) {
        if (source.SessionKey != null) {
            this.SessionKey = new String(source.SessionKey);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SessionKey", this.SessionKey);

    }
}
